#include "..\script_component.hpp"

/*
 * Function: ramdb_db_fnc_hashRemoveId
 * Author: Creedcoder, J.Schmidt
 * Edit: 07.15.2024
 * Copyright © 2024 Creedcoder, J.Schmidt, All rights reserved
 *
 * Do not edit without permission!
 *
 * This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
 * To view a copy of this license, vist https://creativecommons.org/licenses/by-nc-sa/4.0/ or send a letter to Creative Commons,
 * PO Box 1866, Mountain View, CA 94042
 *
 * [Description]
 * Remove field from hash stored at key from DB.
 *
 * Arguments:
 * 0: Name of stored key with hash <STRING> (default: "")
 * 1: Name of stored hash key field <STRING> (default: "")
 *
 * Return Value:
 * N/A
 *
 * Examples:
 * ["myKey", "myField"] call ramdb_db_fnc_hashRemoveId (Server or Singleplayer Only)
 * ["myKey", "myField"] remoteExecCall ["ramdb_db_fnc_hashRemoveId", 2, false] (Multiplayer Only)
 *
 * Public: Yes
 */

params [["_key", "", [""]], ["_keyField", "", [""]]];

#ifdef __A3__DEBUG__
    diag_log text format ["ArmaRAMDb: 'ramdb_db_fnc_hashRemoveId' Key: '%1', KeyField: '%2'", _key, _keyField];
#endif

if (_key == "" || _keyField == "") exitWith {
    diag_log text format ["ArmaRAMDb: 'ramdb_db_fnc_hashRemoveId' Invalid Input for Key '%1' or KeyField '%2'", _key, _keyField];
};

"ArmaRAMDb" callExtension ["hremid", [_key, _keyField]];